public with sharing class TestDesigner {
    
    public void testDesigner(){
    	String packageId = 'aIKu3LNwvclCtAMOeEH-ciVpzvE=';
    	String senderAuthenticationToken = createSenderAuthenticationToken(packageId);
    	System.debug('new designer url: ' + buildRedirectToDesignerForUserAuthenticationTokenNew(senderAuthenticationToken,packageId));
    	System.debug('classic designer url: ' + buildRedirectToDesignerForUserAuthenticationTokenClassic(senderAuthenticationToken,packageId));
    }
    
    
    public String buildRedirectToDesignerForUserAuthenticationTokenNew(String senderAuthenticationToken, String packageId){
    	e_SignLive_Connection_Settings__c connectionSettings = e_SignLive_Connection_Settings__c.getInstance('Main');    
        String endpointWithoutAPI = connectionSettings.Endpoint__c.substringBeforeLast('/api');
        return endpointWithoutAPI + '/auth?senderAuthenticationToken='+ senderAuthenticationToken + '&target=' + endpointWithoutAPI + '/a/transaction/'+packageId+'/designer';
    }
    public String buildRedirectToDesignerForUserAuthenticationTokenClassic(String senderAuthenticationToken, String packageId){
    	e_SignLive_Connection_Settings__c connectionSettings = e_SignLive_Connection_Settings__c.getInstance('Main');    
        String endpointWithoutAPI = connectionSettings.Endpoint__c.substringBeforeLast('/api');
        return endpointWithoutAPI + '/auth?authenticationToken='+ senderAuthenticationToken + '&target=' + endpointWithoutAPI + '/designer/'+packageId;
    }
    
    
	public String createSenderAuthenticationToken(String packageId){
		String requestPayload = '{  "packageId": "'+packageId+'"}';
    	String resourceUrl = '/authenticationTokens/sender';
        HttpResponse response = doPost(resourceUrl, requestPayload);
		
        // Check response
        if(response.getStatusCode() == 200){
        	try
            {
            	Map<String,Object> responseObject = (Map<String,Object>)JSON.deserializeUntyped(response.getBody());
            	String senderAuthenticationToken =  (String)responseObject.get('value');
            	return senderAuthenticationToken;
            }
            catch(Exception e)
            {
                throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error converting signer Authentication Tokens json ' + e.getMessage());
            }
        }else{
            throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error build Redirect To Signing For Signer ' + response.getStatusCode() + ' - ' + response.getStatus() + ' - ' +  response.getBody());
        }
    }
    
    private HttpResponse doPost(String resourceUrl, String requestBody)
    {
        e_SignLive_Connection_Settings__c connectionSettings = e_SignLive_Connection_Settings__c.getInstance('Main');    
        //Cleanup requestBody string before sending it out
        String outboundRequestBody = ESignLiveJSONHelper.prepareOutboundJSON(requestBody);
        System.debug('=> outboundRequestBody:'+outboundRequestBody);

        // Build Request
        HttpRequest request = new HttpRequest();

        request.setEndpoint(connectionSettings.Endpoint__c + resourceUrl);
        request.setBody(outboundRequestBody);
        request.setMethod('POST');
        request.setHeader('Authorization', 'Basic ' + connectionSettings.API_Key__c);
        request.setHeader('Content-type', 'application/json');
        request.setHeader('Accept', 'application/json');

        // Send Request
        HttpResponse response = (new Http()).send(request);

        return response;
    }
    
    public String createPackage() {
        //Create esl client
        ESignLiveSDK sdk = new ESignLiveSDK();
         
        //Create package
        ESignLiveAPIObjects.Package_x pkg = new ESignLiveAPIObjects.Package_x();
        pkg.name = 'Test Designer - ' + Datetime.now().format();
         
        //Prepare Documents Blob
        String document1Name = 'Sample Document';
        StaticResource sr = [SELECT Id, Body FROM StaticResource WHERE Name = 'testdoc1' LIMIT 1];
        Map<String,Blob> documentBlobMap = new Map<String,Blob>();
        documentBlobMap.put(document1Name, sr.Body);
         
         
        String packageId = sdk.createPackage(pkg, documentBlobMap);
        System.debug('PackageId: ' + packageId);
        
        return packageId;   
    }
}